# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Security.EnterpriseData")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.networking
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class DataProtectionStatus(enum.IntEnum):
    PROTECTED_TO_OTHER_IDENTITY = 0
    PROTECTED = 1
    REVOKED = 2
    UNPROTECTED = 3
    LICENSE_EXPIRED = 4
    ACCESS_SUSPENDED = 5

class EnforcementLevel(enum.IntEnum):
    NO_PROTECTION = 0
    SILENT = 1
    OVERRIDE = 2
    BLOCK = 3

class FileProtectionStatus(enum.IntEnum):
    UNDETERMINED = 0
    UNKNOWN = 0
    UNPROTECTED = 1
    REVOKED = 2
    PROTECTED = 3
    PROTECTED_BY_OTHER_USER = 4
    PROTECTED_TO_OTHER_ENTERPRISE = 5
    NOT_PROTECTABLE = 6
    PROTECTED_TO_OTHER_IDENTITY = 7
    LICENSE_EXPIRED = 8
    ACCESS_SUSPENDED = 9
    FILE_IN_USE = 10

class ProtectedImportExportStatus(enum.IntEnum):
    OK = 0
    UNDETERMINED = 1
    UNPROTECTED = 2
    REVOKED = 3
    NOT_ROAMABLE = 4
    PROTECTED_TO_OTHER_IDENTITY = 5
    LICENSE_EXPIRED = 6
    ACCESS_SUSPENDED = 7

class ProtectionPolicyAuditAction(enum.IntEnum):
    DECRYPT = 0
    COPY_TO_LOCATION = 1
    SEND_TO_RECIPIENT = 2
    OTHER = 3

class ProtectionPolicyEvaluationResult(enum.IntEnum):
    ALLOWED = 0
    BLOCKED = 1
    CONSENT_REQUIRED = 2

class ProtectionPolicyRequestAccessBehavior(enum.IntEnum):
    DECRYPT = 0
    TREAT_OVERRIDE_POLICY_AS_BLOCK = 1

_ns_module._register_DataProtectionStatus(DataProtectionStatus)
_ns_module._register_EnforcementLevel(EnforcementLevel)
_ns_module._register_FileProtectionStatus(FileProtectionStatus)
_ns_module._register_ProtectedImportExportStatus(ProtectedImportExportStatus)
_ns_module._register_ProtectionPolicyAuditAction(ProtectionPolicyAuditAction)
_ns_module._register_ProtectionPolicyEvaluationResult(ProtectionPolicyEvaluationResult)
_ns_module._register_ProtectionPolicyRequestAccessBehavior(ProtectionPolicyRequestAccessBehavior)

BufferProtectUnprotectResult = _ns_module.BufferProtectUnprotectResult
DataProtectionInfo = _ns_module.DataProtectionInfo
DataProtectionManager = _ns_module.DataProtectionManager
FileProtectionInfo = _ns_module.FileProtectionInfo
FileProtectionManager = _ns_module.FileProtectionManager
FileRevocationManager = _ns_module.FileRevocationManager
FileUnprotectOptions = _ns_module.FileUnprotectOptions
ProtectedAccessResumedEventArgs = _ns_module.ProtectedAccessResumedEventArgs
ProtectedAccessSuspendingEventArgs = _ns_module.ProtectedAccessSuspendingEventArgs
ProtectedContainerExportResult = _ns_module.ProtectedContainerExportResult
ProtectedContainerImportResult = _ns_module.ProtectedContainerImportResult
ProtectedContentRevokedEventArgs = _ns_module.ProtectedContentRevokedEventArgs
ProtectedFileCreateResult = _ns_module.ProtectedFileCreateResult
ProtectionPolicyAuditInfo = _ns_module.ProtectionPolicyAuditInfo
ProtectionPolicyManager = _ns_module.ProtectionPolicyManager
ThreadNetworkContext = _ns_module.ThreadNetworkContext



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.media.core
import winsdk.windows.storage
import winsdk.windows.storage.streams

class AudioEncodingQuality(enum.IntEnum):
    AUTO = 0
    HIGH = 1
    MEDIUM = 2
    LOW = 3

class MediaMirroringOptions(enum.IntFlag):
    NONE = 0
    HORIZONTAL = 0x1
    VERTICAL = 0x2

class MediaPixelFormat(enum.IntEnum):
    NV12 = 0
    BGRA8 = 1
    P010 = 2

class MediaRotation(enum.IntEnum):
    NONE = 0
    CLOCKWISE90_DEGREES = 1
    CLOCKWISE180_DEGREES = 2
    CLOCKWISE270_DEGREES = 3

class MediaThumbnailFormat(enum.IntEnum):
    BMP = 0
    BGRA8 = 1

class SphericalVideoFrameFormat(enum.IntEnum):
    NONE = 0
    UNSUPPORTED = 1
    EQUIRECTANGULAR = 2

class StereoscopicVideoPackingMode(enum.IntEnum):
    NONE = 0
    SIDE_BY_SIDE = 1
    TOP_BOTTOM = 2

class VideoEncodingQuality(enum.IntEnum):
    AUTO = 0
    H_D1080P = 1
    H_D720P = 2
    WVGA = 3
    NTSC = 4
    PAL = 5
    VGA = 6
    QVGA = 7
    UHD2160P = 8
    UHD4320P = 9

Self = typing.TypeVar('Self')

class AudioEncodingProperties(winsdk.system.Object):
    sample_rate: winsdk.system.UInt32
    channel_count: winsdk.system.UInt32
    bits_per_sample: winsdk.system.UInt32
    bitrate: winsdk.system.UInt32
    is_spatial: winsdk.system.Boolean
    subtype: str
    properties: typing.Optional[MediaPropertySet]
    type: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AudioEncodingProperties: ...
    def __new__(cls: typing.Type[AudioEncodingProperties]) -> AudioEncodingProperties:...
    def copy(self) -> typing.Optional[AudioEncodingProperties]: ...
    @staticmethod
    def create_aac(sample_rate: winsdk.system.UInt32, channel_count: winsdk.system.UInt32, bitrate: winsdk.system.UInt32) -> typing.Optional[AudioEncodingProperties]: ...
    @staticmethod
    def create_aac_adts(sample_rate: winsdk.system.UInt32, channel_count: winsdk.system.UInt32, bitrate: winsdk.system.UInt32) -> typing.Optional[AudioEncodingProperties]: ...
    @staticmethod
    def create_alac(sample_rate: winsdk.system.UInt32, channel_count: winsdk.system.UInt32, bits_per_sample: winsdk.system.UInt32) -> typing.Optional[AudioEncodingProperties]: ...
    @staticmethod
    def create_flac(sample_rate: winsdk.system.UInt32, channel_count: winsdk.system.UInt32, bits_per_sample: winsdk.system.UInt32) -> typing.Optional[AudioEncodingProperties]: ...
    @staticmethod
    def create_mp3(sample_rate: winsdk.system.UInt32, channel_count: winsdk.system.UInt32, bitrate: winsdk.system.UInt32) -> typing.Optional[AudioEncodingProperties]: ...
    @staticmethod
    def create_pcm(sample_rate: winsdk.system.UInt32, channel_count: winsdk.system.UInt32, bits_per_sample: winsdk.system.UInt32) -> typing.Optional[AudioEncodingProperties]: ...
    @staticmethod
    def create_wma(sample_rate: winsdk.system.UInt32, channel_count: winsdk.system.UInt32, bitrate: winsdk.system.UInt32) -> typing.Optional[AudioEncodingProperties]: ...
    def get_format_user_data(self) -> winsdk.system.Array[winsdk.system.UInt8]: ...
    def set_format_user_data(self, value: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...

class ContainerEncodingProperties(winsdk.system.Object):
    subtype: str
    properties: typing.Optional[MediaPropertySet]
    type: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContainerEncodingProperties: ...
    def __new__(cls: typing.Type[ContainerEncodingProperties]) -> ContainerEncodingProperties:...
    def copy(self) -> typing.Optional[ContainerEncodingProperties]: ...

class H264ProfileIds(winsdk.system.Object):
    baseline: typing.ClassVar[winsdk.system.Int32]
    constrained_baseline: typing.ClassVar[winsdk.system.Int32]
    extended: typing.ClassVar[winsdk.system.Int32]
    high: typing.ClassVar[winsdk.system.Int32]
    high10: typing.ClassVar[winsdk.system.Int32]
    high422: typing.ClassVar[winsdk.system.Int32]
    high444: typing.ClassVar[winsdk.system.Int32]
    main: typing.ClassVar[winsdk.system.Int32]
    multiview_high: typing.ClassVar[winsdk.system.Int32]
    stereo_high: typing.ClassVar[winsdk.system.Int32]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> H264ProfileIds: ...

class ImageEncodingProperties(winsdk.system.Object):
    width: winsdk.system.UInt32
    height: winsdk.system.UInt32
    subtype: str
    properties: typing.Optional[MediaPropertySet]
    type: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ImageEncodingProperties: ...
    def __new__(cls: typing.Type[ImageEncodingProperties]) -> ImageEncodingProperties:...
    def copy(self) -> typing.Optional[ImageEncodingProperties]: ...
    @staticmethod
    def create_bmp() -> typing.Optional[ImageEncodingProperties]: ...
    @staticmethod
    def create_heif() -> typing.Optional[ImageEncodingProperties]: ...
    @staticmethod
    def create_jpeg() -> typing.Optional[ImageEncodingProperties]: ...
    @staticmethod
    def create_jpeg_x_r() -> typing.Optional[ImageEncodingProperties]: ...
    @staticmethod
    def create_png() -> typing.Optional[ImageEncodingProperties]: ...
    @staticmethod
    def create_uncompressed(format: MediaPixelFormat) -> typing.Optional[ImageEncodingProperties]: ...

class MediaEncodingProfile(winsdk.system.Object):
    video: typing.Optional[VideoEncodingProperties]
    container: typing.Optional[ContainerEncodingProperties]
    audio: typing.Optional[AudioEncodingProperties]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaEncodingProfile: ...
    def __new__(cls: typing.Type[MediaEncodingProfile]) -> MediaEncodingProfile:...
    @staticmethod
    def create_alac(quality: AudioEncodingQuality) -> typing.Optional[MediaEncodingProfile]: ...
    @staticmethod
    def create_avi(quality: VideoEncodingQuality) -> typing.Optional[MediaEncodingProfile]: ...
    @staticmethod
    def create_flac(quality: AudioEncodingQuality) -> typing.Optional[MediaEncodingProfile]: ...
    @staticmethod
    def create_from_file_async(file: typing.Optional[winsdk.windows.storage.IStorageFile]) -> winsdk.windows.foundation.IAsyncOperation[MediaEncodingProfile]: ...
    @staticmethod
    def create_from_stream_async(stream: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]) -> winsdk.windows.foundation.IAsyncOperation[MediaEncodingProfile]: ...
    @staticmethod
    def create_hevc(quality: VideoEncodingQuality) -> typing.Optional[MediaEncodingProfile]: ...
    @staticmethod
    def create_m4a(quality: AudioEncodingQuality) -> typing.Optional[MediaEncodingProfile]: ...
    @staticmethod
    def create_mp3(quality: AudioEncodingQuality) -> typing.Optional[MediaEncodingProfile]: ...
    @staticmethod
    def create_mp4(quality: VideoEncodingQuality) -> typing.Optional[MediaEncodingProfile]: ...
    @staticmethod
    def create_wav(quality: AudioEncodingQuality) -> typing.Optional[MediaEncodingProfile]: ...
    @staticmethod
    def create_wma(quality: AudioEncodingQuality) -> typing.Optional[MediaEncodingProfile]: ...
    @staticmethod
    def create_wmv(quality: VideoEncodingQuality) -> typing.Optional[MediaEncodingProfile]: ...
    def get_audio_tracks(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.media.core.AudioStreamDescriptor]]: ...
    def get_timed_metadata_tracks(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.media.core.TimedMetadataStreamDescriptor]]: ...
    def get_video_tracks(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.media.core.VideoStreamDescriptor]]: ...
    def set_audio_tracks(self, value: typing.Iterable[winsdk.windows.media.core.AudioStreamDescriptor]) -> None: ...
    def set_timed_metadata_tracks(self, value: typing.Iterable[winsdk.windows.media.core.TimedMetadataStreamDescriptor]) -> None: ...
    def set_video_tracks(self, value: typing.Iterable[winsdk.windows.media.core.VideoStreamDescriptor]) -> None: ...

class MediaEncodingSubtypes(winsdk.system.Object):
    asf: typing.ClassVar[str]
    aac: typing.ClassVar[str]
    aac_adts: typing.ClassVar[str]
    ac3: typing.ClassVar[str]
    amr_nb: typing.ClassVar[str]
    amr_wb: typing.ClassVar[str]
    argb32: typing.ClassVar[str]
    mpeg1: typing.ClassVar[str]
    avi: typing.ClassVar[str]
    bgra8: typing.ClassVar[str]
    bmp: typing.ClassVar[str]
    eac3: typing.ClassVar[str]
    float: typing.ClassVar[str]
    gif: typing.ClassVar[str]
    h263: typing.ClassVar[str]
    h264: typing.ClassVar[str]
    h264_es: typing.ClassVar[str]
    hevc: typing.ClassVar[str]
    hevc_es: typing.ClassVar[str]
    iyuv: typing.ClassVar[str]
    jpeg: typing.ClassVar[str]
    jpeg_xr: typing.ClassVar[str]
    mjpg: typing.ClassVar[str]
    mp3: typing.ClassVar[str]
    mpeg: typing.ClassVar[str]
    mpeg2: typing.ClassVar[str]
    mpeg4: typing.ClassVar[str]
    nv12: typing.ClassVar[str]
    pcm: typing.ClassVar[str]
    png: typing.ClassVar[str]
    rgb24: typing.ClassVar[str]
    rgb32: typing.ClassVar[str]
    tiff: typing.ClassVar[str]
    wave: typing.ClassVar[str]
    wma8: typing.ClassVar[str]
    wma9: typing.ClassVar[str]
    wmv3: typing.ClassVar[str]
    wvc1: typing.ClassVar[str]
    yuy2: typing.ClassVar[str]
    yv12: typing.ClassVar[str]
    d16: typing.ClassVar[str]
    l16: typing.ClassVar[str]
    l8: typing.ClassVar[str]
    vp9: typing.ClassVar[str]
    alac: typing.ClassVar[str]
    flac: typing.ClassVar[str]
    p010: typing.ClassVar[str]
    heif: typing.ClassVar[str]
    srt: typing.ClassVar[str]
    ssa: typing.ClassVar[str]
    vob_sub: typing.ClassVar[str]
    pgs: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaEncodingSubtypes: ...

class MediaPropertySet(winsdk.system.Object, typing.MutableMapping[winsdk.system.Guid, winsdk.system.Object]):
    size: winsdk.system.UInt32
    def __len__(self) -> int: ...
    def __iter__(self) -> typing.Iterator[winsdk.system.Guid]: ...
    def __contains__(self, key: object) -> bool:...
    def __setitem__(self, key: winsdk.system.Guid, value: winsdk.system.Object) -> None: ...
    def __getitem__(self, key: winsdk.system.Guid) -> winsdk.system.Object: ...
    def __delitem__(self, key: winsdk.system.Guid) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPropertySet: ...
    def __new__(cls: typing.Type[MediaPropertySet]) -> MediaPropertySet:...
    def clear(self) -> None: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[winsdk.windows.foundation.collections.IKeyValuePair[winsdk.system.Guid, winsdk.system.Object]]]: ...
    def get_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IMapView[winsdk.system.Guid, winsdk.system.Object]]: ...
    def has_key(self, key: winsdk.system.Guid) -> winsdk.system.Boolean: ...
    def insert(self, key: winsdk.system.Guid, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...
    def lookup(self, key: winsdk.system.Guid) -> typing.Optional[winsdk.system.Object]: ...
    def remove(self, key: winsdk.system.Guid) -> None: ...

class MediaRatio(winsdk.system.Object):
    numerator: winsdk.system.UInt32
    denominator: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaRatio: ...

class Mpeg2ProfileIds(winsdk.system.Object):
    high: typing.ClassVar[winsdk.system.Int32]
    main: typing.ClassVar[winsdk.system.Int32]
    signal_noise_ratio_scalable: typing.ClassVar[winsdk.system.Int32]
    simple: typing.ClassVar[winsdk.system.Int32]
    spatially_scalable: typing.ClassVar[winsdk.system.Int32]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Mpeg2ProfileIds: ...

class TimedMetadataEncodingProperties(winsdk.system.Object):
    subtype: str
    properties: typing.Optional[MediaPropertySet]
    type: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TimedMetadataEncodingProperties: ...
    def __new__(cls: typing.Type[TimedMetadataEncodingProperties]) -> TimedMetadataEncodingProperties:...
    def copy(self) -> typing.Optional[TimedMetadataEncodingProperties]: ...
    @staticmethod
    def create_pgs() -> typing.Optional[TimedMetadataEncodingProperties]: ...
    @staticmethod
    def create_srt() -> typing.Optional[TimedMetadataEncodingProperties]: ...
    @staticmethod
    def create_ssa(format_user_data: winsdk.system.Array[winsdk.system.UInt8]) -> typing.Optional[TimedMetadataEncodingProperties]: ...
    @staticmethod
    def create_vob_sub(format_user_data: winsdk.system.Array[winsdk.system.UInt8]) -> typing.Optional[TimedMetadataEncodingProperties]: ...
    def get_format_user_data(self) -> winsdk.system.Array[winsdk.system.UInt8]: ...
    def set_format_user_data(self, value: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...

class VideoEncodingProperties(winsdk.system.Object):
    subtype: str
    type: str
    properties: typing.Optional[MediaPropertySet]
    width: winsdk.system.UInt32
    height: winsdk.system.UInt32
    bitrate: winsdk.system.UInt32
    pixel_aspect_ratio: typing.Optional[MediaRatio]
    frame_rate: typing.Optional[MediaRatio]
    profile_id: winsdk.system.Int32
    stereoscopic_video_packing_mode: StereoscopicVideoPackingMode
    spherical_video_frame_format: SphericalVideoFrameFormat
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VideoEncodingProperties: ...
    def __new__(cls: typing.Type[VideoEncodingProperties]) -> VideoEncodingProperties:...
    def copy(self) -> typing.Optional[VideoEncodingProperties]: ...
    @staticmethod
    def create_h264() -> typing.Optional[VideoEncodingProperties]: ...
    @staticmethod
    def create_hevc() -> typing.Optional[VideoEncodingProperties]: ...
    @staticmethod
    def create_mpeg2() -> typing.Optional[VideoEncodingProperties]: ...
    @staticmethod
    def create_uncompressed(subtype: str, width: winsdk.system.UInt32, height: winsdk.system.UInt32) -> typing.Optional[VideoEncodingProperties]: ...
    def get_format_user_data(self) -> winsdk.system.Array[winsdk.system.UInt8]: ...
    def set_format_user_data(self, value: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...

class IMediaEncodingProperties(winsdk.system.Object):
    properties: typing.Optional[MediaPropertySet]
    subtype: str
    type: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IMediaEncodingProperties: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.ui

class CoreInputViewKind(enum.IntEnum):
    DEFAULT = 0
    KEYBOARD = 1
    HANDWRITING = 2
    EMOJI = 3
    SYMBOLS = 4
    CLIPBOARD = 5
    DICTATION = 6

class CoreInputViewOcclusionKind(enum.IntEnum):
    DOCKED = 0
    FLOATING = 1
    OVERLAY = 2

class CoreInputViewXYFocusTransferDirection(enum.IntEnum):
    UP = 0
    RIGHT = 1
    DOWN = 2
    LEFT = 3

Self = typing.TypeVar('Self')

class CoreFrameworkInputView(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CoreFrameworkInputView: ...
    @staticmethod
    def get_for_current_view() -> typing.Optional[CoreFrameworkInputView]: ...
    @staticmethod
    def get_for_u_i_context(context: typing.Optional[winsdk.windows.ui.UIContext]) -> typing.Optional[CoreFrameworkInputView]: ...
    def add_occlusions_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[CoreFrameworkInputView, CoreFrameworkInputViewOcclusionsChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_occlusions_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_primary_view_animation_starting(self, handler: winsdk.windows.foundation.TypedEventHandler[CoreFrameworkInputView, CoreFrameworkInputViewAnimationStartingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_primary_view_animation_starting(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class CoreFrameworkInputViewAnimationStartingEventArgs(winsdk.system.Object):
    animation_duration: datetime.timedelta
    framework_animation_recommended: winsdk.system.Boolean
    occlusions: typing.Optional[winsdk.windows.foundation.collections.IVectorView[CoreInputViewOcclusion]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CoreFrameworkInputViewAnimationStartingEventArgs: ...

class CoreFrameworkInputViewOcclusionsChangedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    occlusions: typing.Optional[winsdk.windows.foundation.collections.IVectorView[CoreInputViewOcclusion]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CoreFrameworkInputViewOcclusionsChangedEventArgs: ...

class CoreInputView(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CoreInputView: ...
    def get_core_input_view_occlusions(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[CoreInputViewOcclusion]]: ...
    @staticmethod
    def get_for_current_view() -> typing.Optional[CoreInputView]: ...
    @staticmethod
    def get_for_u_i_context(context: typing.Optional[winsdk.windows.ui.UIContext]) -> typing.Optional[CoreInputView]: ...
    def is_kind_supported(self, type: CoreInputViewKind) -> winsdk.system.Boolean: ...
    def try_hide(self) -> winsdk.system.Boolean: ...
    def try_hide_primary_view(self) -> winsdk.system.Boolean: ...
    @typing.overload
    def try_show(self) -> winsdk.system.Boolean: ...
    @typing.overload
    def try_show(self, type: CoreInputViewKind) -> winsdk.system.Boolean: ...
    def try_show_primary_view(self) -> winsdk.system.Boolean: ...
    def try_transfer_x_y_focus_to_primary_view(self, origin: winsdk.windows.foundation.Rect, direction: CoreInputViewXYFocusTransferDirection) -> winsdk.system.Boolean: ...
    def add_occlusions_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[CoreInputView, CoreInputViewOcclusionsChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_occlusions_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_x_y_focus_transferred_to_primary_view(self, handler: winsdk.windows.foundation.TypedEventHandler[CoreInputView, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_x_y_focus_transferred_to_primary_view(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_x_y_focus_transferring_from_primary_view(self, handler: winsdk.windows.foundation.TypedEventHandler[CoreInputView, CoreInputViewTransferringXYFocusEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_x_y_focus_transferring_from_primary_view(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_primary_view_hiding(self, handler: winsdk.windows.foundation.TypedEventHandler[CoreInputView, CoreInputViewHidingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_primary_view_hiding(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_primary_view_showing(self, handler: winsdk.windows.foundation.TypedEventHandler[CoreInputView, CoreInputViewShowingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_primary_view_showing(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_primary_view_animation_starting(self, handler: winsdk.windows.foundation.TypedEventHandler[CoreInputView, CoreInputViewAnimationStartingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_primary_view_animation_starting(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_supported_kinds_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[CoreInputView, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_supported_kinds_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class CoreInputViewAnimationStartingEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    animation_duration: datetime.timedelta
    occlusions: typing.Optional[winsdk.windows.foundation.collections.IVectorView[CoreInputViewOcclusion]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CoreInputViewAnimationStartingEventArgs: ...

class CoreInputViewHidingEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CoreInputViewHidingEventArgs: ...
    def try_cancel(self) -> winsdk.system.Boolean: ...

class CoreInputViewOcclusion(winsdk.system.Object):
    occluding_rect: winsdk.windows.foundation.Rect
    occlusion_kind: CoreInputViewOcclusionKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CoreInputViewOcclusion: ...

class CoreInputViewOcclusionsChangedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    occlusions: typing.Optional[winsdk.windows.foundation.collections.IVectorView[CoreInputViewOcclusion]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CoreInputViewOcclusionsChangedEventArgs: ...

class CoreInputViewShowingEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CoreInputViewShowingEventArgs: ...
    def try_cancel(self) -> winsdk.system.Boolean: ...

class CoreInputViewTransferringXYFocusEventArgs(winsdk.system.Object):
    transfer_handled: winsdk.system.Boolean
    keep_primary_view_visible: winsdk.system.Boolean
    direction: CoreInputViewXYFocusTransferDirection
    origin: winsdk.windows.foundation.Rect
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CoreInputViewTransferringXYFocusEventArgs: ...

class UISettingsController(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UISettingsController: ...
    @staticmethod
    def request_default_async() -> winsdk.windows.foundation.IAsyncOperation[UISettingsController]: ...
    def set_advanced_effects_enabled(self, value: winsdk.system.Boolean) -> None: ...
    def set_animations_enabled(self, value: winsdk.system.Boolean) -> None: ...
    def set_auto_hide_scroll_bars(self, value: winsdk.system.Boolean) -> None: ...
    def set_message_duration(self, value: winsdk.system.UInt32) -> None: ...
    def set_text_scale_factor(self, value: winsdk.system.Double) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Wallet")

try:
    import winsdk.windows.devices.geolocation
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.ui
except ImportError:
    pass

class WalletActionKind(enum.IntEnum):
    OPEN_ITEM = 0
    TRANSACTION = 1
    MORE_TRANSACTIONS = 2
    MESSAGE = 3
    VERB = 4

class WalletBarcodeSymbology(enum.IntEnum):
    INVALID = 0
    UPCA = 1
    UPCE = 2
    EAN13 = 3
    EAN8 = 4
    ITF = 5
    CODE39 = 6
    CODE128 = 7
    QR = 8
    PDF417 = 9
    AZTEC = 10
    CUSTOM = 100000

class WalletDetailViewPosition(enum.IntEnum):
    HIDDEN = 0
    HEADER_FIELD1 = 1
    HEADER_FIELD2 = 2
    PRIMARY_FIELD1 = 3
    PRIMARY_FIELD2 = 4
    SECONDARY_FIELD1 = 5
    SECONDARY_FIELD2 = 6
    SECONDARY_FIELD3 = 7
    SECONDARY_FIELD4 = 8
    SECONDARY_FIELD5 = 9
    CENTER_FIELD1 = 10
    FOOTER_FIELD1 = 11
    FOOTER_FIELD2 = 12
    FOOTER_FIELD3 = 13
    FOOTER_FIELD4 = 14

class WalletItemKind(enum.IntEnum):
    INVALID = 0
    DEAL = 1
    GENERAL = 2
    PAYMENT_INSTRUMENT = 3
    TICKET = 4
    BOARDING_PASS = 5
    MEMBERSHIP_CARD = 6

class WalletSummaryViewPosition(enum.IntEnum):
    HIDDEN = 0
    FIELD1 = 1
    FIELD2 = 2

_ns_module._register_WalletActionKind(WalletActionKind)
_ns_module._register_WalletBarcodeSymbology(WalletBarcodeSymbology)
_ns_module._register_WalletDetailViewPosition(WalletDetailViewPosition)
_ns_module._register_WalletItemKind(WalletItemKind)
_ns_module._register_WalletSummaryViewPosition(WalletSummaryViewPosition)

WalletBarcode = _ns_module.WalletBarcode
WalletItem = _ns_module.WalletItem
WalletItemCustomProperty = _ns_module.WalletItemCustomProperty
WalletItemStore = _ns_module.WalletItemStore
WalletManager = _ns_module.WalletManager
WalletRelevantLocation = _ns_module.WalletRelevantLocation
WalletTransaction = _ns_module.WalletTransaction
WalletVerb = _ns_module.WalletVerb



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.devices.perception
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.foundation.numerics
import winsdk.windows.graphics.imaging
import winsdk.windows.media

Self = typing.TypeVar('Self')

class KnownPerceptionFrameKind(winsdk.system.Object):
    color: typing.ClassVar[str]
    depth: typing.ClassVar[str]
    infrared: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> KnownPerceptionFrameKind: ...

class PerceptionControlGroup(winsdk.system.Object):
    frame_provider_ids: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionControlGroup: ...
    def __new__(cls: typing.Type[PerceptionControlGroup], ids: typing.Iterable[str]) -> PerceptionControlGroup:...

class PerceptionCorrelation(winsdk.system.Object):
    orientation: winsdk.windows.foundation.numerics.Quaternion
    position: winsdk.windows.foundation.numerics.Vector3
    target_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionCorrelation: ...
    def __new__(cls: typing.Type[PerceptionCorrelation], target_id: str, position: winsdk.windows.foundation.numerics.Vector3, orientation: winsdk.windows.foundation.numerics.Quaternion) -> PerceptionCorrelation:...

class PerceptionCorrelationGroup(winsdk.system.Object):
    relative_locations: typing.Optional[winsdk.windows.foundation.collections.IVectorView[PerceptionCorrelation]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionCorrelationGroup: ...
    def __new__(cls: typing.Type[PerceptionCorrelationGroup], relative_locations: typing.Iterable[PerceptionCorrelation]) -> PerceptionCorrelationGroup:...

class PerceptionFaceAuthenticationGroup(winsdk.system.Object):
    frame_provider_ids: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionFaceAuthenticationGroup: ...
    def __new__(cls: typing.Type[PerceptionFaceAuthenticationGroup], ids: typing.Iterable[str], start_handler: typing.Optional[PerceptionStartFaceAuthenticationHandler], stop_handler: typing.Optional[PerceptionStopFaceAuthenticationHandler]) -> PerceptionFaceAuthenticationGroup:...

class PerceptionFrame(winsdk.system.Object):
    relative_time: datetime.timedelta
    frame_data: typing.Optional[winsdk.windows.foundation.IMemoryBuffer]
    properties: typing.Optional[winsdk.windows.foundation.collections.ValueSet]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionFrame: ...

class PerceptionFrameProviderInfo(winsdk.system.Object):
    id: str
    hidden: winsdk.system.Boolean
    frame_kind: str
    display_name: str
    device_kind: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionFrameProviderInfo: ...
    def __new__(cls: typing.Type[PerceptionFrameProviderInfo]) -> PerceptionFrameProviderInfo:...

class PerceptionFrameProviderManagerService(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionFrameProviderManagerService: ...
    @staticmethod
    def publish_frame_for_provider(provider: typing.Optional[IPerceptionFrameProvider], frame: typing.Optional[PerceptionFrame]) -> None: ...
    @staticmethod
    def register_control_group(manager: typing.Optional[IPerceptionFrameProviderManager], control_group: typing.Optional[PerceptionControlGroup]) -> None: ...
    @staticmethod
    def register_correlation_group(manager: typing.Optional[IPerceptionFrameProviderManager], correlation_group: typing.Optional[PerceptionCorrelationGroup]) -> None: ...
    @staticmethod
    def register_face_authentication_group(manager: typing.Optional[IPerceptionFrameProviderManager], face_authentication_group: typing.Optional[PerceptionFaceAuthenticationGroup]) -> None: ...
    @staticmethod
    def register_frame_provider_info(manager: typing.Optional[IPerceptionFrameProviderManager], frame_provider_info: typing.Optional[PerceptionFrameProviderInfo]) -> None: ...
    @staticmethod
    def unregister_control_group(manager: typing.Optional[IPerceptionFrameProviderManager], control_group: typing.Optional[PerceptionControlGroup]) -> None: ...
    @staticmethod
    def unregister_correlation_group(manager: typing.Optional[IPerceptionFrameProviderManager], correlation_group: typing.Optional[PerceptionCorrelationGroup]) -> None: ...
    @staticmethod
    def unregister_face_authentication_group(manager: typing.Optional[IPerceptionFrameProviderManager], face_authentication_group: typing.Optional[PerceptionFaceAuthenticationGroup]) -> None: ...
    @staticmethod
    def unregister_frame_provider_info(manager: typing.Optional[IPerceptionFrameProviderManager], frame_provider_info: typing.Optional[PerceptionFrameProviderInfo]) -> None: ...
    @staticmethod
    def update_availability_for_provider(provider: typing.Optional[IPerceptionFrameProvider], available: winsdk.system.Boolean) -> None: ...

class PerceptionPropertyChangeRequest(winsdk.system.Object):
    status: winsdk.windows.devices.perception.PerceptionFrameSourcePropertyChangeStatus
    name: str
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionPropertyChangeRequest: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class PerceptionVideoFrameAllocator(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionVideoFrameAllocator: ...
    def __new__(cls: typing.Type[PerceptionVideoFrameAllocator], max_outstanding_frame_count_for_write: winsdk.system.UInt32, format: winsdk.windows.graphics.imaging.BitmapPixelFormat, resolution: winsdk.windows.foundation.Size, alpha: winsdk.windows.graphics.imaging.BitmapAlphaMode) -> PerceptionVideoFrameAllocator:...
    def allocate_frame(self) -> typing.Optional[PerceptionFrame]: ...
    def close(self) -> None: ...
    def copy_from_video_frame(self, frame: typing.Optional[winsdk.windows.media.VideoFrame]) -> typing.Optional[PerceptionFrame]: ...

class IPerceptionFrameProvider(winsdk.system.Object):
    available: winsdk.system.Boolean
    frame_provider_info: typing.Optional[PerceptionFrameProviderInfo]
    properties: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IPerceptionFrameProvider: ...
    def close(self) -> None: ...
    def set_property(self, value: typing.Optional[PerceptionPropertyChangeRequest]) -> None: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...

class IPerceptionFrameProviderManager(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IPerceptionFrameProviderManager: ...
    def close(self) -> None: ...
    def get_frame_provider(self, frame_provider_info: typing.Optional[PerceptionFrameProviderInfo]) -> typing.Optional[IPerceptionFrameProvider]: ...

PerceptionStartFaceAuthenticationHandler = typing.Callable[[typing.Optional[PerceptionFaceAuthenticationGroup]], winsdk.system.Boolean]

PerceptionStopFaceAuthenticationHandler = typing.Callable[[typing.Optional[PerceptionFaceAuthenticationGroup]], None]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Bluetooth.Advertisement")

try:
    import winsdk.windows.devices.bluetooth
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class BluetoothLEAdvertisementFlags(enum.IntFlag):
    NONE = 0
    LIMITED_DISCOVERABLE_MODE = 0x1
    GENERAL_DISCOVERABLE_MODE = 0x2
    CLASSIC_NOT_SUPPORTED = 0x4
    DUAL_MODE_CONTROLLER_CAPABLE = 0x8
    DUAL_MODE_HOST_CAPABLE = 0x10

class BluetoothLEAdvertisementPublisherStatus(enum.IntEnum):
    CREATED = 0
    WAITING = 1
    STARTED = 2
    STOPPING = 3
    STOPPED = 4
    ABORTED = 5

class BluetoothLEAdvertisementType(enum.IntEnum):
    CONNECTABLE_UNDIRECTED = 0
    CONNECTABLE_DIRECTED = 1
    SCANNABLE_UNDIRECTED = 2
    NON_CONNECTABLE_UNDIRECTED = 3
    SCAN_RESPONSE = 4
    EXTENDED = 5

class BluetoothLEAdvertisementWatcherStatus(enum.IntEnum):
    CREATED = 0
    STARTED = 1
    STOPPING = 2
    STOPPED = 3
    ABORTED = 4

class BluetoothLEScanningMode(enum.IntEnum):
    PASSIVE = 0
    ACTIVE = 1
    NONE = 2

_ns_module._register_BluetoothLEAdvertisementFlags(BluetoothLEAdvertisementFlags)
_ns_module._register_BluetoothLEAdvertisementPublisherStatus(BluetoothLEAdvertisementPublisherStatus)
_ns_module._register_BluetoothLEAdvertisementType(BluetoothLEAdvertisementType)
_ns_module._register_BluetoothLEAdvertisementWatcherStatus(BluetoothLEAdvertisementWatcherStatus)
_ns_module._register_BluetoothLEScanningMode(BluetoothLEScanningMode)

BluetoothLEAdvertisement = _ns_module.BluetoothLEAdvertisement
BluetoothLEAdvertisementBytePattern = _ns_module.BluetoothLEAdvertisementBytePattern
BluetoothLEAdvertisementDataSection = _ns_module.BluetoothLEAdvertisementDataSection
BluetoothLEAdvertisementDataTypes = _ns_module.BluetoothLEAdvertisementDataTypes
BluetoothLEAdvertisementFilter = _ns_module.BluetoothLEAdvertisementFilter
BluetoothLEAdvertisementPublisher = _ns_module.BluetoothLEAdvertisementPublisher
BluetoothLEAdvertisementPublisherStatusChangedEventArgs = _ns_module.BluetoothLEAdvertisementPublisherStatusChangedEventArgs
BluetoothLEAdvertisementReceivedEventArgs = _ns_module.BluetoothLEAdvertisementReceivedEventArgs
BluetoothLEAdvertisementWatcher = _ns_module.BluetoothLEAdvertisementWatcher
BluetoothLEAdvertisementWatcherStoppedEventArgs = _ns_module.BluetoothLEAdvertisementWatcherStoppedEventArgs
BluetoothLEManufacturerData = _ns_module.BluetoothLEManufacturerData



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.StartScreen")

try:
    import winsdk.windows.applicationmodel.core
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.perception.spatial
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui
except ImportError:
    pass

try:
    import winsdk.windows.ui.popups
except ImportError:
    pass

class ForegroundText(enum.IntEnum):
    DARK = 0
    LIGHT = 1

class JumpListItemKind(enum.IntEnum):
    ARGUMENTS = 0
    SEPARATOR = 1

class JumpListSystemGroupKind(enum.IntEnum):
    NONE = 0
    FREQUENT = 1
    RECENT = 2

class TileMixedRealityModelActivationBehavior(enum.IntEnum):
    DEFAULT = 0
    NONE = 1

class TileOptions(enum.IntFlag):
    NONE = 0
    SHOW_NAME_ON_LOGO = 0x1
    SHOW_NAME_ON_WIDE_LOGO = 0x2
    COPY_ON_DEPLOYMENT = 0x4

class TileSize(enum.IntEnum):
    DEFAULT = 0
    SQUARE30X30 = 1
    SQUARE70X70 = 2
    SQUARE150X150 = 3
    WIDE310X150 = 4
    SQUARE310X310 = 5
    SQUARE71X71 = 6
    SQUARE44X44 = 7

_ns_module._register_ForegroundText(ForegroundText)
_ns_module._register_JumpListItemKind(JumpListItemKind)
_ns_module._register_JumpListSystemGroupKind(JumpListSystemGroupKind)
_ns_module._register_TileMixedRealityModelActivationBehavior(TileMixedRealityModelActivationBehavior)
_ns_module._register_TileOptions(TileOptions)
_ns_module._register_TileSize(TileSize)

JumpList = _ns_module.JumpList
JumpListItem = _ns_module.JumpListItem
SecondaryTile = _ns_module.SecondaryTile
SecondaryTileVisualElements = _ns_module.SecondaryTileVisualElements
StartScreenManager = _ns_module.StartScreenManager
TileMixedRealityModel = _ns_module.TileMixedRealityModel
VisualElementsRequest = _ns_module.VisualElementsRequest
VisualElementsRequestDeferral = _ns_module.VisualElementsRequestDeferral
VisualElementsRequestedEventArgs = _ns_module.VisualElementsRequestedEventArgs



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.DataTransfer.ShareTarget")

try:
    import winsdk.windows.applicationmodel.contacts
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.datatransfer
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass


QuickLink = _ns_module.QuickLink
ShareOperation = _ns_module.ShareOperation



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system

class DragDropModifiers(enum.IntFlag):
    NONE = 0
    SHIFT = 0x1
    CONTROL = 0x2
    ALT = 0x4
    LEFT_BUTTON = 0x8
    MIDDLE_BUTTON = 0x10
    RIGHT_BUTTON = 0x20

Self = typing.TypeVar('Self')




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.devices.enumeration
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.graphics.directx.direct3d11
import winsdk.windows.graphics.imaging
import winsdk.windows.media
import winsdk.windows.media.capture.core
import winsdk.windows.media.capture.frames
import winsdk.windows.media.core
import winsdk.windows.media.devices
import winsdk.windows.media.effects
import winsdk.windows.media.mediaproperties
import winsdk.windows.security.authentication.web
import winsdk.windows.security.credentials
import winsdk.windows.storage
import winsdk.windows.storage.streams
import winsdk.windows.system
import winsdk.windows.ui.windowmanagement

class AppBroadcastCameraCaptureState(enum.IntEnum):
    STOPPED = 0
    STARTED = 1
    FAILED = 2

class AppBroadcastCameraOverlayLocation(enum.IntEnum):
    TOP_LEFT = 0
    TOP_CENTER = 1
    TOP_RIGHT = 2
    MIDDLE_LEFT = 3
    MIDDLE_CENTER = 4
    MIDDLE_RIGHT = 5
    BOTTOM_LEFT = 6
    BOTTOM_CENTER = 7
    BOTTOM_RIGHT = 8

class AppBroadcastCameraOverlaySize(enum.IntEnum):
    SMALL = 0
    MEDIUM = 1
    LARGE = 2

class AppBroadcastCaptureTargetType(enum.IntEnum):
    APP_VIEW = 0
    ENTIRE_DISPLAY = 1

class AppBroadcastExitBroadcastModeReason(enum.IntEnum):
    NORMAL_EXIT = 0
    USER_CANCELED = 1
    AUTHORIZATION_FAIL = 2
    FOREGROUND_APP_ACTIVATED = 3

class AppBroadcastMicrophoneCaptureState(enum.IntEnum):
    STOPPED = 0
    STARTED = 1
    FAILED = 2

class AppBroadcastPlugInState(enum.IntEnum):
    UNKNOWN = 0
    INITIALIZED = 1
    MICROSOFT_SIGN_IN_REQUIRED = 2
    O_AUTH_SIGN_IN_REQUIRED = 3
    PROVIDER_SIGN_IN_REQUIRED = 4
    IN_BANDWIDTH_TEST = 5
    READY_TO_BROADCAST = 6

class AppBroadcastPreviewState(enum.IntEnum):
    STARTED = 0
    STOPPED = 1
    FAILED = 2

class AppBroadcastSignInResult(enum.IntEnum):
    SUCCESS = 0
    AUTHENTICATION_FAILED = 1
    UNAUTHORIZED = 2
    SERVICE_UNAVAILABLE = 3
    UNKNOWN = 4

class AppBroadcastSignInState(enum.IntEnum):
    NOT_SIGNED_IN = 0
    MICROSOFT_SIGN_IN_IN_PROGRESS = 1
    MICROSOFT_SIGN_IN_COMPLETE = 2
    O_AUTH_SIGN_IN_IN_PROGRESS = 3
    O_AUTH_SIGN_IN_COMPLETE = 4

class AppBroadcastStreamState(enum.IntEnum):
    INITIALIZING = 0
    STREAM_READY = 1
    STARTED = 2
    PAUSED = 3
    TERMINATED = 4

class AppBroadcastTerminationReason(enum.IntEnum):
    NORMAL_TERMINATION = 0
    LOST_CONNECTION_TO_SERVICE = 1
    NO_NETWORK_CONNECTIVITY = 2
    SERVICE_ABORT = 3
    SERVICE_ERROR = 4
    SERVICE_UNAVAILABLE = 5
    INTERNAL_ERROR = 6
    UNSUPPORTED_FORMAT = 7
    BACKGROUND_TASK_TERMINATED = 8
    BACKGROUND_TASK_UNRESPONSIVE = 9

class AppBroadcastVideoEncodingBitrateMode(enum.IntEnum):
    CUSTOM = 0
    AUTO = 1

class AppBroadcastVideoEncodingResolutionMode(enum.IntEnum):
    CUSTOM = 0
    AUTO = 1

class AppCaptureHistoricalBufferLengthUnit(enum.IntEnum):
    MEGABYTES = 0
    SECONDS = 1

class AppCaptureMetadataPriority(enum.IntEnum):
    INFORMATIONAL = 0
    IMPORTANT = 1

class AppCaptureMicrophoneCaptureState(enum.IntEnum):
    STOPPED = 0
    STARTED = 1
    FAILED = 2

class AppCaptureRecordingState(enum.IntEnum):
    IN_PROGRESS = 0
    COMPLETED = 1
    FAILED = 2

class AppCaptureVideoEncodingBitrateMode(enum.IntEnum):
    CUSTOM = 0
    HIGH = 1
    STANDARD = 2

class AppCaptureVideoEncodingFrameRateMode(enum.IntEnum):
    STANDARD = 0
    HIGH = 1

class AppCaptureVideoEncodingResolutionMode(enum.IntEnum):
    CUSTOM = 0
    HIGH = 1
    STANDARD = 2

class CameraCaptureUIMaxPhotoResolution(enum.IntEnum):
    HIGHEST_AVAILABLE = 0
    VERY_SMALL_QVGA = 1
    SMALL_VGA = 2
    MEDIUM_XGA = 3
    LARGE3_M = 4
    VERY_LARGE5_M = 5

class CameraCaptureUIMaxVideoResolution(enum.IntEnum):
    HIGHEST_AVAILABLE = 0
    LOW_DEFINITION = 1
    STANDARD_DEFINITION = 2
    HIGH_DEFINITION = 3

class CameraCaptureUIMode(enum.IntEnum):
    PHOTO_OR_VIDEO = 0
    PHOTO = 1
    VIDEO = 2

class CameraCaptureUIPhotoFormat(enum.IntEnum):
    JPEG = 0
    PNG = 1
    JPEG_X_R = 2

class CameraCaptureUIVideoFormat(enum.IntEnum):
    MP4 = 0
    WMV = 1

class ForegroundActivationArgument(enum.IntEnum):
    SIGN_IN_REQUIRED = 0
    MORE_SETTINGS = 1

class GameBarCommand(enum.IntEnum):
    OPEN_GAME_BAR = 0
    RECORD_HISTORICAL_BUFFER = 1
    TOGGLE_START_STOP_RECORD = 2
    START_RECORD = 3
    STOP_RECORD = 4
    TAKE_SCREENSHOT = 5
    START_BROADCAST = 6
    STOP_BROADCAST = 7
    PAUSE_BROADCAST = 8
    RESUME_BROADCAST = 9
    TOGGLE_START_STOP_BROADCAST = 10
    TOGGLE_MICROPHONE_CAPTURE = 11
    TOGGLE_CAMERA_CAPTURE = 12
    TOGGLE_RECORDING_INDICATOR = 13

class GameBarCommandOrigin(enum.IntEnum):
    SHORTCUT_KEY = 0
    CORTANA = 1
    APP_COMMAND = 2

class GameBarServicesDisplayMode(enum.IntEnum):
    WINDOWED = 0
    FULL_SCREEN_EXCLUSIVE = 1

class GameBarTargetCapturePolicy(enum.IntEnum):
    ENABLED_BY_SYSTEM = 0
    ENABLED_BY_USER = 1
    NOT_ENABLED = 2
    PROHIBITED_BY_SYSTEM = 3
    PROHIBITED_BY_PUBLISHER = 4

class KnownVideoProfile(enum.IntEnum):
    VIDEO_RECORDING = 0
    HIGH_QUALITY_PHOTO = 1
    BALANCED_VIDEO_AND_PHOTO = 2
    VIDEO_CONFERENCING = 3
    PHOTO_SEQUENCE = 4
    HIGH_FRAME_RATE = 5
    VARIABLE_PHOTO_SEQUENCE = 6
    HDR_WITH_WCG_VIDEO = 7
    HDR_WITH_WCG_PHOTO = 8
    VIDEO_HDR8 = 9
    COMPRESSED_CAMERA = 10

class MediaCaptureDeviceExclusiveControlReleaseMode(enum.IntEnum):
    ON_DISPOSE = 0
    ON_ALL_STREAMS_STOPPED = 1

class MediaCaptureDeviceExclusiveControlStatus(enum.IntEnum):
    EXCLUSIVE_CONTROL_AVAILABLE = 0
    SHARED_READ_ONLY_AVAILABLE = 1

class MediaCaptureMemoryPreference(enum.IntEnum):
    AUTO = 0
    CPU = 1

class MediaCaptureSharingMode(enum.IntEnum):
    EXCLUSIVE_CONTROL = 0
    SHARED_READ_ONLY = 1

class MediaCaptureThermalStatus(enum.IntEnum):
    NORMAL = 0
    OVERHEATED = 1

class MediaCategory(enum.IntEnum):
    OTHER = 0
    COMMUNICATIONS = 1
    MEDIA = 2
    GAME_CHAT = 3
    SPEECH = 4
    FAR_FIELD_SPEECH = 5
    UNIFORM_SPEECH = 6
    VOICE_TYPING = 7

class MediaStreamType(enum.IntEnum):
    VIDEO_PREVIEW = 0
    VIDEO_RECORD = 1
    AUDIO = 2
    PHOTO = 3
    METADATA = 4

class PhotoCaptureSource(enum.IntEnum):
    AUTO = 0
    VIDEO_PREVIEW = 1
    PHOTO = 2

class PowerlineFrequency(enum.IntEnum):
    DISABLED = 0
    FIFTY_HERTZ = 1
    SIXTY_HERTZ = 2
    AUTO = 3

class StreamingCaptureMode(enum.IntEnum):
    AUDIO_AND_VIDEO = 0
    AUDIO = 1
    VIDEO = 2

class VideoDeviceCharacteristic(enum.IntEnum):
    ALL_STREAMS_INDEPENDENT = 0
    PREVIEW_RECORD_STREAMS_IDENTICAL = 1
    PREVIEW_PHOTO_STREAMS_IDENTICAL = 2
    RECORD_PHOTO_STREAMS_IDENTICAL = 3
    ALL_STREAMS_IDENTICAL = 4

class VideoRotation(enum.IntEnum):
    NONE = 0
    CLOCKWISE90_DEGREES = 1
    CLOCKWISE180_DEGREES = 2
    CLOCKWISE270_DEGREES = 3

Self = typing.TypeVar('Self')

class WhiteBalanceGain:
    r: winsdk.system.Double
    g: winsdk.system.Double
    b: winsdk.system.Double
    def __new__(cls: typing.Type[WhiteBalanceGain], r: winsdk.system.Double, g: winsdk.system.Double, b: winsdk.system.Double) -> WhiteBalanceGain: ...

class AdvancedCapturedPhoto(winsdk.system.Object):
    context: typing.Optional[winsdk.system.Object]
    frame: typing.Optional[CapturedFrame]
    mode: winsdk.windows.media.devices.AdvancedPhotoMode
    frame_bounds_relative_to_reference_photo: typing.Optional[typing.Optional[winsdk.windows.foundation.Rect]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AdvancedCapturedPhoto: ...

class AdvancedPhotoCapture(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AdvancedPhotoCapture: ...
    @typing.overload
    def capture_async(self) -> winsdk.windows.foundation.IAsyncOperation[AdvancedCapturedPhoto]: ...
    @typing.overload
    def capture_async(self, context: typing.Optional[winsdk.system.Object]) -> winsdk.windows.foundation.IAsyncOperation[AdvancedCapturedPhoto]: ...
    def finish_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def add_all_photos_captured(self, handler: winsdk.windows.foundation.TypedEventHandler[AdvancedPhotoCapture, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_all_photos_captured(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_optional_reference_photo_captured(self, handler: winsdk.windows.foundation.TypedEventHandler[AdvancedPhotoCapture, OptionalReferencePhotoCapturedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_optional_reference_photo_captured(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class AppBroadcastBackgroundService(winsdk.system.Object):
    viewer_count: winsdk.system.UInt32
    stream_info: typing.Optional[AppBroadcastBackgroundServiceStreamInfo]
    sign_in_info: typing.Optional[AppBroadcastBackgroundServiceSignInInfo]
    plug_in_state: AppBroadcastPlugInState
    broadcast_title: str
    app_id: str
    title_id: str
    broadcast_language: str
    broadcast_channel: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastBackgroundService: ...
    def terminate_broadcast(self, reason: AppBroadcastTerminationReason, provider_specific_reason: winsdk.system.UInt32) -> None: ...
    def add_heartbeat_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[AppBroadcastBackgroundService, AppBroadcastHeartbeatRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_heartbeat_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_broadcast_channel_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[AppBroadcastBackgroundService, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_broadcast_channel_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_broadcast_language_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[AppBroadcastBackgroundService, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_broadcast_language_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_broadcast_title_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[AppBroadcastBackgroundService, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_broadcast_title_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class AppBroadcastBackgroundServiceSignInInfo(winsdk.system.Object):
    user_name: str
    o_auth_request_uri: typing.Optional[winsdk.windows.foundation.Uri]
    o_auth_callback_uri: typing.Optional[winsdk.windows.foundation.Uri]
    authentication_result: typing.Optional[winsdk.windows.security.authentication.web.WebAuthenticationResult]
    sign_in_state: AppBroadcastSignInState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastBackgroundServiceSignInInfo: ...
    def add_sign_in_state_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[AppBroadcastBackgroundServiceSignInInfo, AppBroadcastSignInStateChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_sign_in_state_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_user_name_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[AppBroadcastBackgroundServiceSignInInfo, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_user_name_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class AppBroadcastBackgroundServiceStreamInfo(winsdk.system.Object):
    desired_video_encoding_bitrate: winsdk.system.UInt64
    bandwidth_test_bitrate: winsdk.system.UInt64
    audio_codec: str
    broadcast_stream_reader: typing.Optional[AppBroadcastStreamReader]
    stream_state: AppBroadcastStreamState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastBackgroundServiceStreamInfo: ...
    def report_problem_with_stream(self) -> None: ...
    def add_stream_state_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[AppBroadcastBackgroundServiceStreamInfo, AppBroadcastStreamStateChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_stream_state_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_video_encoding_bitrate_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[AppBroadcastBackgroundServiceStreamInfo, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_video_encoding_bitrate_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_video_encoding_resolution_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[AppBroadcastBackgroundServiceStreamInfo, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_video_encoding_resolution_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class AppBroadcastCameraCaptureStateChangedEventArgs(winsdk.system.Object):
    error_code: winsdk.system.UInt32
    state: AppBroadcastCameraCaptureState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastCameraCaptureStateChangedEventArgs: ...

class AppBroadcastGlobalSettings(winsdk.system.Object):
    system_audio_gain: winsdk.system.Double
    selected_camera_id: str
    microphone_gain: winsdk.system.Double
    is_microphone_capture_enabled_by_default: winsdk.system.Boolean
    is_echo_cancellation_enabled: winsdk.system.Boolean
    is_cursor_image_capture_enabled: winsdk.system.Boolean
    is_camera_capture_enabled_by_default: winsdk.system.Boolean
    is_audio_capture_enabled: winsdk.system.Boolean
    camera_overlay_size: AppBroadcastCameraOverlaySize
    camera_overlay_location: AppBroadcastCameraOverlayLocation
    has_hardware_encoder: winsdk.system.Boolean
    is_broadcast_enabled: winsdk.system.Boolean
    is_disabled_by_policy: winsdk.system.Boolean
    is_gpu_constrained: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastGlobalSettings: ...

class AppBroadcastHeartbeatRequestedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastHeartbeatRequestedEventArgs: ...

class AppBroadcastManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastManager: ...
    @staticmethod
    def apply_global_settings(value: typing.Optional[AppBroadcastGlobalSettings]) -> None: ...
    @staticmethod
    def apply_provider_settings(value: typing.Optional[AppBroadcastProviderSettings]) -> None: ...
    @staticmethod
    def get_global_settings() -> typing.Optional[AppBroadcastGlobalSettings]: ...
    @staticmethod
    def get_provider_settings() -> typing.Optional[AppBroadcastProviderSettings]: ...

class AppBroadcastMicrophoneCaptureStateChangedEventArgs(winsdk.system.Object):
    error_code: winsdk.system.UInt32
    state: AppBroadcastMicrophoneCaptureState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastMicrophoneCaptureStateChangedEventArgs: ...

class AppBroadcastPlugIn(winsdk.system.Object):
    app_id: str
    display_name: str
    logo: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    provider_settings: typing.Optional[AppBroadcastProviderSettings]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastPlugIn: ...

class AppBroadcastPlugInManager(winsdk.system.Object):
    default_plug_in: typing.Optional[AppBroadcastPlugIn]
    is_broadcast_provider_available: winsdk.system.Boolean
    plug_in_list: typing.Optional[winsdk.windows.foundation.collections.IVectorView[AppBroadcastPlugIn]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastPlugInManager: ...
    @staticmethod
    def get_default() -> typing.Optional[AppBroadcastPlugInManager]: ...
    @staticmethod
    def get_for_user(user: typing.Optional[winsdk.windows.system.User]) -> typing.Optional[AppBroadcastPlugInManager]: ...

class AppBroadcastPlugInStateChangedEventArgs(winsdk.system.Object):
    plug_in_state: AppBroadcastPlugInState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastPlugInStateChangedEventArgs: ...

class AppBroadcastPreview(winsdk.system.Object):
    error_code: typing.Optional[typing.Optional[winsdk.system.UInt32]]
    preview_state: AppBroadcastPreviewState
    preview_stream_reader: typing.Optional[AppBroadcastPreviewStreamReader]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastPreview: ...
    def stop_preview(self) -> None: ...
    def add_preview_state_changed(self, value: winsdk.windows.foundation.TypedEventHandler[AppBroadcastPreview, AppBroadcastPreviewStateChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_preview_state_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class AppBroadcastPreviewStateChangedEventArgs(winsdk.system.Object):
    error_code: winsdk.system.UInt32
    preview_state: AppBroadcastPreviewState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastPreviewStateChangedEventArgs: ...

class AppBroadcastPreviewStreamReader(winsdk.system.Object):
    video_bitmap_alpha_mode: winsdk.windows.graphics.imaging.BitmapAlphaMode
    video_bitmap_pixel_format: winsdk.windows.graphics.imaging.BitmapPixelFormat
    video_height: winsdk.system.UInt32
    video_stride: winsdk.system.UInt32
    video_width: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastPreviewStreamReader: ...
    def try_get_next_video_frame(self) -> typing.Optional[AppBroadcastPreviewStreamVideoFrame]: ...
    def add_video_frame_arrived(self, value: winsdk.windows.foundation.TypedEventHandler[AppBroadcastPreviewStreamReader, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_video_frame_arrived(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class AppBroadcastPreviewStreamVideoFrame(winsdk.system.Object):
    video_buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    video_header: typing.Optional[AppBroadcastPreviewStreamVideoHeader]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastPreviewStreamVideoFrame: ...

class AppBroadcastPreviewStreamVideoHeader(winsdk.system.Object):
    absolute_timestamp: datetime.datetime
    duration: datetime.timedelta
    frame_id: winsdk.system.UInt64
    relative_timestamp: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastPreviewStreamVideoHeader: ...

class AppBroadcastProviderSettings(winsdk.system.Object):
    video_encoding_resolution_mode: AppBroadcastVideoEncodingResolutionMode
    video_encoding_bitrate_mode: AppBroadcastVideoEncodingBitrateMode
    default_broadcast_title: str
    custom_video_encoding_width: winsdk.system.UInt32
    custom_video_encoding_height: winsdk.system.UInt32
    custom_video_encoding_bitrate: winsdk.system.UInt32
    audio_encoding_bitrate: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastProviderSettings: ...

class AppBroadcastServices(winsdk.system.Object):
    capture_target_type: AppBroadcastCaptureTargetType
    broadcast_title: str
    broadcast_language: str
    can_capture: winsdk.system.Boolean
    state: typing.Optional[AppBroadcastState]
    user_name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastServices: ...
    def enter_broadcast_mode_async(self, plug_in: typing.Optional[AppBroadcastPlugIn]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.UInt32]: ...
    def exit_broadcast_mode(self, reason: AppBroadcastExitBroadcastModeReason) -> None: ...
    def pause_broadcast(self) -> None: ...
    def resume_broadcast(self) -> None: ...
    def start_broadcast(self) -> None: ...
    def start_preview(self, desired_size: winsdk.windows.foundation.Size) -> typing.Optional[AppBroadcastPreview]: ...

class AppBroadcastSignInStateChangedEventArgs(winsdk.system.Object):
    result: AppBroadcastSignInResult
    sign_in_state: AppBroadcastSignInState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastSignInStateChangedEventArgs: ...

class AppBroadcastState(winsdk.system.Object):
    sign_in_state: AppBroadcastSignInState
    should_capture_microphone: winsdk.system.Boolean
    should_capture_camera: winsdk.system.Boolean
    authentication_result: typing.Optional[winsdk.windows.security.authentication.web.WebAuthenticationResult]
    is_capture_target_running: winsdk.system.Boolean
    microphone_capture_error: winsdk.system.UInt32
    microphone_capture_state: AppBroadcastMicrophoneCaptureState
    o_auth_callback_uri: typing.Optional[winsdk.windows.foundation.Uri]
    o_auth_request_uri: typing.Optional[winsdk.windows.foundation.Uri]
    plug_in_state: AppBroadcastPlugInState
    camera_capture_error: winsdk.system.UInt32
    camera_capture_state: AppBroadcastCameraCaptureState
    encoded_video_size: winsdk.windows.foundation.Size
    stream_state: AppBroadcastStreamState
    termination_reason: AppBroadcastTerminationReason
    termination_reason_plug_in_specific: winsdk.system.UInt32
    viewer_count: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastState: ...
    def restart_camera_capture(self) -> None: ...
    def restart_microphone_capture(self) -> None: ...
    def add_camera_capture_state_changed(self, value: winsdk.windows.foundation.TypedEventHandler[AppBroadcastState, AppBroadcastCameraCaptureStateChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_camera_capture_state_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_capture_target_closed(self, value: winsdk.windows.foundation.TypedEventHandler[AppBroadcastState, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_capture_target_closed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_microphone_capture_state_changed(self, value: winsdk.windows.foundation.TypedEventHandler[AppBroadcastState, AppBroadcastMicrophoneCaptureStateChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_microphone_capture_state_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_plug_in_state_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[AppBroadcastState, AppBroadcastPlugInStateChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_plug_in_state_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_stream_state_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[AppBroadcastState, AppBroadcastStreamStateChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_stream_state_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_viewer_count_changed(self, value: winsdk.windows.foundation.TypedEventHandler[AppBroadcastState, AppBroadcastViewerCountChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_viewer_count_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class AppBroadcastStreamAudioFrame(winsdk.system.Object):
    audio_buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    audio_header: typing.Optional[AppBroadcastStreamAudioHeader]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastStreamAudioFrame: ...

class AppBroadcastStreamAudioHeader(winsdk.system.Object):
    absolute_timestamp: datetime.datetime
    duration: datetime.timedelta
    frame_id: winsdk.system.UInt64
    has_discontinuity: winsdk.system.Boolean
    relative_timestamp: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastStreamAudioHeader: ...

class AppBroadcastStreamReader(winsdk.system.Object):
    audio_aac_sequence: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    audio_bitrate: winsdk.system.UInt32
    audio_channels: winsdk.system.UInt32
    audio_sample_rate: winsdk.system.UInt32
    video_bitrate: winsdk.system.UInt32
    video_height: winsdk.system.UInt32
    video_width: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastStreamReader: ...
    def try_get_next_audio_frame(self) -> typing.Optional[AppBroadcastStreamAudioFrame]: ...
    def try_get_next_video_frame(self) -> typing.Optional[AppBroadcastStreamVideoFrame]: ...
    def add_audio_frame_arrived(self, value: winsdk.windows.foundation.TypedEventHandler[AppBroadcastStreamReader, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_audio_frame_arrived(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_video_frame_arrived(self, value: winsdk.windows.foundation.TypedEventHandler[AppBroadcastStreamReader, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_video_frame_arrived(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class AppBroadcastStreamStateChangedEventArgs(winsdk.system.Object):
    stream_state: AppBroadcastStreamState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastStreamStateChangedEventArgs: ...

class AppBroadcastStreamVideoFrame(winsdk.system.Object):
    video_buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    video_header: typing.Optional[AppBroadcastStreamVideoHeader]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastStreamVideoFrame: ...

class AppBroadcastStreamVideoHeader(winsdk.system.Object):
    absolute_timestamp: datetime.datetime
    duration: datetime.timedelta
    frame_id: winsdk.system.UInt64
    has_discontinuity: winsdk.system.Boolean
    is_key_frame: winsdk.system.Boolean
    relative_timestamp: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastStreamVideoHeader: ...

class AppBroadcastTriggerDetails(winsdk.system.Object):
    background_service: typing.Optional[AppBroadcastBackgroundService]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastTriggerDetails: ...

class AppBroadcastViewerCountChangedEventArgs(winsdk.system.Object):
    viewer_count: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppBroadcastViewerCountChangedEventArgs: ...

class AppCapture(winsdk.system.Object):
    is_capturing_audio: winsdk.system.Boolean
    is_capturing_video: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppCapture: ...
    @staticmethod
    def get_for_current_view() -> typing.Optional[AppCapture]: ...
    @staticmethod
    def set_allowed_async(allowed: winsdk.system.Boolean) -> winsdk.windows.foundation.IAsyncAction: ...
    def add_capturing_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[AppCapture, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_capturing_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class AppCaptureAlternateShortcutKeys(winsdk.system.Object):
    toggle_recording_key_modifiers: winsdk.windows.system.VirtualKeyModifiers
    toggle_recording_key: winsdk.windows.system.VirtualKey
    toggle_recording_indicator_key_modifiers: winsdk.windows.system.VirtualKeyModifiers
    toggle_recording_indicator_key: winsdk.windows.system.VirtualKey
    toggle_game_bar_key_modifiers: winsdk.windows.system.VirtualKeyModifiers
    toggle_game_bar_key: winsdk.windows.system.VirtualKey
    take_screenshot_key_modifiers: winsdk.windows.system.VirtualKeyModifiers
    take_screenshot_key: winsdk.windows.system.VirtualKey
    save_historical_video_key_modifiers: winsdk.windows.system.VirtualKeyModifiers
    save_historical_video_key: winsdk.windows.system.VirtualKey
    toggle_microphone_capture_key_modifiers: winsdk.windows.system.VirtualKeyModifiers
    toggle_microphone_capture_key: winsdk.windows.system.VirtualKey
    toggle_camera_capture_key_modifiers: winsdk.windows.system.VirtualKeyModifiers
    toggle_camera_capture_key: winsdk.windows.system.VirtualKey
    toggle_broadcast_key_modifiers: winsdk.windows.system.VirtualKeyModifiers
    toggle_broadcast_key: winsdk.windows.system.VirtualKey
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppCaptureAlternateShortcutKeys: ...

class AppCaptureDurationGeneratedEventArgs(winsdk.system.Object):
    duration: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppCaptureDurationGeneratedEventArgs: ...

class AppCaptureFileGeneratedEventArgs(winsdk.system.Object):
    file: typing.Optional[winsdk.windows.storage.StorageFile]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppCaptureFileGeneratedEventArgs: ...

class AppCaptureManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppCaptureManager: ...
    @staticmethod
    def apply_settings(app_capture_settings: typing.Optional[AppCaptureSettings]) -> None: ...
    @staticmethod
    def get_current_settings() -> typing.Optional[AppCaptureSettings]: ...

class AppCaptureMetadataWriter(winsdk.system.Object):
    remaining_storage_bytes_available: winsdk.system.UInt64
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppCaptureMetadataWriter: ...
    def __new__(cls: typing.Type[AppCaptureMetadataWriter]) -> AppCaptureMetadataWriter:...
    def add_double_event(self, name: str, value: winsdk.system.Double, priority: AppCaptureMetadataPriority) -> None: ...
    def add_int32_event(self, name: str, value: winsdk.system.Int32, priority: AppCaptureMetadataPriority) -> None: ...
    def add_string_event(self, name: str, value: str, priority: AppCaptureMetadataPriority) -> None: ...
    def close(self) -> None: ...
    def start_double_state(self, name: str, value: winsdk.system.Double, priority: AppCaptureMetadataPriority) -> None: ...
    def start_int32_state(self, name: str, value: winsdk.system.Int32, priority: AppCaptureMetadataPriority) -> None: ...
    def start_string_state(self, name: str, value: str, priority: AppCaptureMetadataPriority) -> None: ...
    def stop_all_states(self) -> None: ...
    def stop_state(self, name: str) -> None: ...
    def add_metadata_purged(self, handler: winsdk.windows.foundation.TypedEventHandler[AppCaptureMetadataWriter, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_metadata_purged(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class AppCaptureMicrophoneCaptureStateChangedEventArgs(winsdk.system.Object):
    error_code: winsdk.system.UInt32
    state: AppCaptureMicrophoneCaptureState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppCaptureMicrophoneCaptureStateChangedEventArgs: ...

class AppCaptureRecordOperation(winsdk.system.Object):
    duration: typing.Optional[typing.Optional[datetime.timedelta]]
    error_code: typing.Optional[typing.Optional[winsdk.system.UInt32]]
    file: typing.Optional[winsdk.windows.storage.StorageFile]
    is_file_truncated: typing.Optional[typing.Optional[winsdk.system.Boolean]]
    state: AppCaptureRecordingState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppCaptureRecordOperation: ...
    def stop_recording(self) -> None: ...
    def add_duration_generated(self, value: winsdk.windows.foundation.TypedEventHandler[AppCaptureRecordOperation, AppCaptureDurationGeneratedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_duration_generated(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_file_generated(self, value: winsdk.windows.foundation.TypedEventHandler[AppCaptureRecordOperation, AppCaptureFileGeneratedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_file_generated(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_state_changed(self, value: winsdk.windows.foundation.TypedEventHandler[AppCaptureRecordOperation, AppCaptureRecordingStateChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_state_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class AppCaptureRecordingStateChangedEventArgs(winsdk.system.Object):
    error_code: winsdk.system.UInt32
    state: AppCaptureRecordingState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppCaptureRecordingStateChangedEventArgs: ...

class AppCaptureServices(winsdk.system.Object):
    can_capture: winsdk.system.Boolean
    state: typing.Optional[AppCaptureState]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppCaptureServices: ...
    def record(self) -> typing.Optional[AppCaptureRecordOperation]: ...
    def record_time_span(self, start_time: datetime.datetime, duration: datetime.timedelta) -> typing.Optional[AppCaptureRecordOperation]: ...

class AppCaptureSettings(winsdk.system.Object):
    is_historical_capture_on_wireless_display_allowed: winsdk.system.Boolean
    video_encoding_bitrate_mode: AppCaptureVideoEncodingBitrateMode
    is_historical_capture_on_battery_allowed: winsdk.system.Boolean
    is_audio_capture_enabled: winsdk.system.Boolean
    is_app_capture_enabled: winsdk.system.Boolean
    app_capture_destination_folder: typing.Optional[winsdk.windows.storage.StorageFolder]
    historical_buffer_length: winsdk.system.UInt32
    is_historical_capture_enabled: winsdk.system.Boolean
    custom_video_encoding_width: winsdk.system.UInt32
    custom_video_encoding_height: winsdk.system.UInt32
    custom_video_encoding_bitrate: winsdk.system.UInt32
    audio_encoding_bitrate: winsdk.system.UInt32
    historical_buffer_length_unit: AppCaptureHistoricalBufferLengthUnit
    video_encoding_resolution_mode: AppCaptureVideoEncodingResolutionMode
    screenshot_destination_folder: typing.Optional[winsdk.windows.storage.StorageFolder]
    maximum_record_length: datetime.timedelta
    has_hardware_encoder: winsdk.system.Boolean
    is_cpu_constrained: winsdk.system.Boolean
    is_memory_constrained: winsdk.system.Boolean
    is_disabled_by_policy: winsdk.system.Boolean
    alternate_shortcut_keys: typing.Optional[AppCaptureAlternateShortcutKeys]
    is_gpu_constrained: winsdk.system.Boolean
    is_microphone_capture_enabled: winsdk.system.Boolean
    video_encoding_frame_rate_mode: AppCaptureVideoEncodingFrameRateMode
    system_audio_gain: winsdk.system.Double
    microphone_gain: winsdk.system.Double
    is_microphone_capture_enabled_by_default: winsdk.system.Boolean
    is_echo_cancellation_enabled: winsdk.system.Boolean
    is_cursor_image_capture_enabled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppCaptureSettings: ...

class AppCaptureState(winsdk.system.Object):
    should_capture_microphone: winsdk.system.Boolean
    is_historical_capture_enabled: winsdk.system.Boolean
    is_target_running: winsdk.system.Boolean
    microphone_capture_error: winsdk.system.UInt32
    microphone_capture_state: AppCaptureMicrophoneCaptureState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppCaptureState: ...
    def restart_microphone_capture(self) -> None: ...
    def add_capture_target_closed(self, value: winsdk.windows.foundation.TypedEventHandler[AppCaptureState, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_capture_target_closed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_microphone_capture_state_changed(self, value: winsdk.windows.foundation.TypedEventHandler[AppCaptureState, AppCaptureMicrophoneCaptureStateChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_microphone_capture_state_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class CameraCaptureUI(winsdk.system.Object):
    photo_settings: typing.Optional[CameraCaptureUIPhotoCaptureSettings]
    video_settings: typing.Optional[CameraCaptureUIVideoCaptureSettings]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CameraCaptureUI: ...
    def __new__(cls: typing.Type[CameraCaptureUI]) -> CameraCaptureUI:...
    def capture_file_async(self, mode: CameraCaptureUIMode) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageFile]: ...

class CameraCaptureUIPhotoCaptureSettings(winsdk.system.Object):
    max_resolution: CameraCaptureUIMaxPhotoResolution
    format: CameraCaptureUIPhotoFormat
    cropped_size_in_pixels: winsdk.windows.foundation.Size
    cropped_aspect_ratio: winsdk.windows.foundation.Size
    allow_cropping: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CameraCaptureUIPhotoCaptureSettings: ...

class CameraCaptureUIVideoCaptureSettings(winsdk.system.Object):
    max_resolution: CameraCaptureUIMaxVideoResolution
    max_duration_in_seconds: winsdk.system.Single
    format: CameraCaptureUIVideoFormat
    allow_trimming: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CameraCaptureUIVideoCaptureSettings: ...

class CameraOptionsUI(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CameraOptionsUI: ...
    @staticmethod
    def show(media_capture: typing.Optional[MediaCapture]) -> None: ...

class CapturedFrame(winsdk.system.Object):
    height: winsdk.system.UInt32
    width: winsdk.system.UInt32
    bitmap_properties: typing.Optional[winsdk.windows.graphics.imaging.BitmapPropertySet]
    control_values: typing.Optional[CapturedFrameControlValues]
    software_bitmap: typing.Optional[winsdk.windows.graphics.imaging.SoftwareBitmap]
    content_type: str
    size: winsdk.system.UInt64
    can_read: winsdk.system.Boolean
    can_write: winsdk.system.Boolean
    position: winsdk.system.UInt64
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CapturedFrame: ...
    def clone_stream(self) -> typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]: ...
    def close(self) -> None: ...
    def flush_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def get_input_stream_at(self, position: winsdk.system.UInt64) -> typing.Optional[winsdk.windows.storage.streams.IInputStream]: ...
    def get_output_stream_at(self, position: winsdk.system.UInt64) -> typing.Optional[winsdk.windows.storage.streams.IOutputStream]: ...
    def read_async(self, buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer], count: winsdk.system.UInt32, options: winsdk.windows.storage.streams.InputStreamOptions) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.windows.storage.streams.IBuffer, winsdk.system.UInt32]: ...
    def seek(self, position: winsdk.system.UInt64) -> None: ...
    def write_async(self, buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt32, winsdk.system.UInt32]: ...

class CapturedFrameControlValues(winsdk.system.Object):
    exposure: typing.Optional[typing.Optional[datetime.timedelta]]
    exposure_compensation: typing.Optional[typing.Optional[winsdk.system.Single]]
    flash_power_percent: typing.Optional[typing.Optional[winsdk.system.Single]]
    flashed: typing.Optional[typing.Optional[winsdk.system.Boolean]]
    focus: typing.Optional[typing.Optional[winsdk.system.UInt32]]
    iso_speed: typing.Optional[typing.Optional[winsdk.system.UInt32]]
    scene_mode: typing.Optional[typing.Optional[winsdk.windows.media.devices.CaptureSceneMode]]
    white_balance: typing.Optional[typing.Optional[winsdk.system.UInt32]]
    zoom_factor: typing.Optional[typing.Optional[winsdk.system.Single]]
    focus_state: typing.Optional[typing.Optional[winsdk.windows.media.devices.MediaCaptureFocusState]]
    iso_analog_gain: typing.Optional[typing.Optional[winsdk.system.Double]]
    iso_digital_gain: typing.Optional[typing.Optional[winsdk.system.Double]]
    sensor_frame_rate: typing.Optional[winsdk.windows.media.mediaproperties.MediaRatio]
    white_balance_gain: typing.Optional[typing.Optional[WhiteBalanceGain]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CapturedFrameControlValues: ...

class CapturedPhoto(winsdk.system.Object):
    frame: typing.Optional[CapturedFrame]
    thumbnail: typing.Optional[CapturedFrame]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CapturedPhoto: ...

class GameBarServices(winsdk.system.Object):
    app_broadcast_services: typing.Optional[AppBroadcastServices]
    app_capture_services: typing.Optional[AppCaptureServices]
    session_id: str
    target_capture_policy: GameBarTargetCapturePolicy
    target_info: typing.Optional[GameBarServicesTargetInfo]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GameBarServices: ...
    def disable_capture(self) -> None: ...
    def enable_capture(self) -> None: ...
    def add_command_received(self, value: winsdk.windows.foundation.TypedEventHandler[GameBarServices, GameBarServicesCommandEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_command_received(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class GameBarServicesCommandEventArgs(winsdk.system.Object):
    command: GameBarCommand
    origin: GameBarCommandOrigin
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GameBarServicesCommandEventArgs: ...

class GameBarServicesManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GameBarServicesManager: ...
    @staticmethod
    def get_default() -> typing.Optional[GameBarServicesManager]: ...
    def add_game_bar_services_created(self, value: winsdk.windows.foundation.TypedEventHandler[GameBarServicesManager, GameBarServicesManagerGameBarServicesCreatedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_game_bar_services_created(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class GameBarServicesManagerGameBarServicesCreatedEventArgs(winsdk.system.Object):
    game_bar_services: typing.Optional[GameBarServices]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GameBarServicesManagerGameBarServicesCreatedEventArgs: ...

class GameBarServicesTargetInfo(winsdk.system.Object):
    app_id: str
    display_mode: GameBarServicesDisplayMode
    display_name: str
    title_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GameBarServicesTargetInfo: ...

class LowLagMediaRecording(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LowLagMediaRecording: ...
    def finish_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def pause_async(self, behavior: winsdk.windows.media.devices.MediaCapturePauseBehavior) -> winsdk.windows.foundation.IAsyncAction: ...
    def pause_with_result_async(self, behavior: winsdk.windows.media.devices.MediaCapturePauseBehavior) -> winsdk.windows.foundation.IAsyncOperation[MediaCapturePauseResult]: ...
    def resume_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def start_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def stop_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def stop_with_result_async(self) -> winsdk.windows.foundation.IAsyncOperation[MediaCaptureStopResult]: ...

class LowLagPhotoCapture(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LowLagPhotoCapture: ...
    def capture_async(self) -> winsdk.windows.foundation.IAsyncOperation[CapturedPhoto]: ...
    def finish_async(self) -> winsdk.windows.foundation.IAsyncAction: ...

class LowLagPhotoSequenceCapture(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LowLagPhotoSequenceCapture: ...
    def finish_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def start_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def stop_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def add_photo_captured(self, handler: winsdk.windows.foundation.TypedEventHandler[LowLagPhotoSequenceCapture, PhotoCapturedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_photo_captured(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaCapture(winsdk.system.Object):
    audio_device_controller: typing.Optional[winsdk.windows.media.devices.AudioDeviceController]
    media_capture_settings: typing.Optional[MediaCaptureSettings]
    video_device_controller: typing.Optional[winsdk.windows.media.devices.VideoDeviceController]
    camera_stream_state: winsdk.windows.media.devices.CameraStreamState
    thermal_status: MediaCaptureThermalStatus
    frame_sources: typing.Optional[winsdk.windows.foundation.collections.IMapView[str, winsdk.windows.media.capture.frames.MediaFrameSource]]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaCapture: ...
    def __new__(cls: typing.Type[MediaCapture]) -> MediaCapture:...
    def add_audio_effect_async(self, definition: typing.Optional[winsdk.windows.media.effects.IAudioEffectDefinition]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.media.IMediaExtension]: ...
    def add_effect_async(self, media_stream_type: MediaStreamType, effect_activation_i_d: str, effect_settings: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> winsdk.windows.foundation.IAsyncAction: ...
    def add_video_effect_async(self, definition: typing.Optional[winsdk.windows.media.effects.IVideoEffectDefinition], media_stream_type: MediaStreamType) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.media.IMediaExtension]: ...
    def capture_photo_to_storage_file_async(self, type: typing.Optional[winsdk.windows.media.mediaproperties.ImageEncodingProperties], file: typing.Optional[winsdk.windows.storage.IStorageFile]) -> winsdk.windows.foundation.IAsyncAction: ...
    def capture_photo_to_stream_async(self, type: typing.Optional[winsdk.windows.media.mediaproperties.ImageEncodingProperties], stream: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]) -> winsdk.windows.foundation.IAsyncAction: ...
    def clear_effects_async(self, media_stream_type: MediaStreamType) -> winsdk.windows.foundation.IAsyncAction: ...
    def close(self) -> None: ...
    @typing.overload
    def create_frame_reader_async(self, input_source: typing.Optional[winsdk.windows.media.capture.frames.MediaFrameSource]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.media.capture.frames.MediaFrameReader]: ...
    @typing.overload
    def create_frame_reader_async(self, input_source: typing.Optional[winsdk.windows.media.capture.frames.MediaFrameSource], output_subtype: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.media.capture.frames.MediaFrameReader]: ...
    @typing.overload
    def create_frame_reader_async(self, input_source: typing.Optional[winsdk.windows.media.capture.frames.MediaFrameSource], output_subtype: str, output_size: winsdk.windows.graphics.imaging.BitmapSize) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.media.capture.frames.MediaFrameReader]: ...
    def create_multi_source_frame_reader_async(self, input_sources: typing.Iterable[winsdk.windows.media.capture.frames.MediaFrameSource]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.media.capture.frames.MultiSourceMediaFrameReader]: ...
    def create_relative_panel_watcher(self, capture_mode: StreamingCaptureMode, display_region: typing.Optional[winsdk.windows.ui.windowmanagement.DisplayRegion]) -> typing.Optional[MediaCaptureRelativePanelWatcher]: ...
    @staticmethod
    def find_all_video_profiles(video_device_id: str) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[MediaCaptureVideoProfile]]: ...
    @staticmethod
    def find_concurrent_profiles(video_device_id: str) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[MediaCaptureVideoProfile]]: ...
    @staticmethod
    def find_known_video_profiles(video_device_id: str, name: KnownVideoProfile) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[MediaCaptureVideoProfile]]: ...
    def get_encoder_property(self, media_stream_type: MediaStreamType, property_id: winsdk.system.Guid) -> typing.Optional[winsdk.system.Object]: ...
    @typing.overload
    def get_preview_frame_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.media.VideoFrame]: ...
    @typing.overload
    def get_preview_frame_async(self, destination: typing.Optional[winsdk.windows.media.VideoFrame]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.media.VideoFrame]: ...
    def get_preview_mirroring(self) -> winsdk.system.Boolean: ...
    def get_preview_rotation(self) -> VideoRotation: ...
    def get_record_rotation(self) -> VideoRotation: ...
    @typing.overload
    def initialize_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def initialize_async(self, media_capture_initialization_settings: typing.Optional[MediaCaptureInitializationSettings]) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def is_video_profile_supported(video_device_id: str) -> winsdk.system.Boolean: ...
    def pause_record_async(self, behavior: winsdk.windows.media.devices.MediaCapturePauseBehavior) -> winsdk.windows.foundation.IAsyncAction: ...
    def pause_record_with_result_async(self, behavior: winsdk.windows.media.devices.MediaCapturePauseBehavior) -> winsdk.windows.foundation.IAsyncOperation[MediaCapturePauseResult]: ...
    def prepare_advanced_photo_capture_async(self, encoding_properties: typing.Optional[winsdk.windows.media.mediaproperties.ImageEncodingProperties]) -> winsdk.windows.foundation.IAsyncOperation[AdvancedPhotoCapture]: ...
    def prepare_low_lag_photo_capture_async(self, type: typing.Optional[winsdk.windows.media.mediaproperties.ImageEncodingProperties]) -> winsdk.windows.foundation.IAsyncOperation[LowLagPhotoCapture]: ...
    def prepare_low_lag_photo_sequence_capture_async(self, type: typing.Optional[winsdk.windows.media.mediaproperties.ImageEncodingProperties]) -> winsdk.windows.foundation.IAsyncOperation[LowLagPhotoSequenceCapture]: ...
    @typing.overload
    def prepare_low_lag_record_to_custom_sink_async(self, encoding_profile: typing.Optional[winsdk.windows.media.mediaproperties.MediaEncodingProfile], custom_media_sink: typing.Optional[winsdk.windows.media.IMediaExtension]) -> winsdk.windows.foundation.IAsyncOperation[LowLagMediaRecording]: ...
    @typing.overload
    def prepare_low_lag_record_to_custom_sink_async(self, encoding_profile: typing.Optional[winsdk.windows.media.mediaproperties.MediaEncodingProfile], custom_sink_activation_id: str, custom_sink_settings: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> winsdk.windows.foundation.IAsyncOperation[LowLagMediaRecording]: ...
    def prepare_low_lag_record_to_storage_file_async(self, encoding_profile: typing.Optional[winsdk.windows.media.mediaproperties.MediaEncodingProfile], file: typing.Optional[winsdk.windows.storage.IStorageFile]) -> winsdk.windows.foundation.IAsyncOperation[LowLagMediaRecording]: ...
    def prepare_low_lag_record_to_stream_async(self, encoding_profile: typing.Optional[winsdk.windows.media.mediaproperties.MediaEncodingProfile], stream: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]) -> winsdk.windows.foundation.IAsyncOperation[LowLagMediaRecording]: ...
    def prepare_variable_photo_sequence_capture_async(self, type: typing.Optional[winsdk.windows.media.mediaproperties.ImageEncodingProperties]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.media.capture.core.VariablePhotoSequenceCapture]: ...
    def remove_effect_async(self, effect: typing.Optional[winsdk.windows.media.IMediaExtension]) -> winsdk.windows.foundation.IAsyncAction: ...
    def resume_record_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def set_encoder_property(self, media_stream_type: MediaStreamType, property_id: winsdk.system.Guid, property_value: typing.Optional[winsdk.system.Object]) -> None: ...
    def set_encoding_properties_async(self, media_stream_type: MediaStreamType, media_encoding_properties: typing.Optional[winsdk.windows.media.mediaproperties.IMediaEncodingProperties], encoder_properties: typing.Optional[winsdk.windows.media.mediaproperties.MediaPropertySet]) -> winsdk.windows.foundation.IAsyncAction: ...
    def set_preview_mirroring(self, value: winsdk.system.Boolean) -> None: ...
    def set_preview_rotation(self, value: VideoRotation) -> None: ...
    def set_record_rotation(self, value: VideoRotation) -> None: ...
    def start_preview_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def start_preview_to_custom_sink_async(self, encoding_profile: typing.Optional[winsdk.windows.media.mediaproperties.MediaEncodingProfile], custom_media_sink: typing.Optional[winsdk.windows.media.IMediaExtension]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def start_preview_to_custom_sink_async(self, encoding_profile: typing.Optional[winsdk.windows.media.mediaproperties.MediaEncodingProfile], custom_sink_activation_id: str, custom_sink_settings: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def start_record_to_custom_sink_async(self, encoding_profile: typing.Optional[winsdk.windows.media.mediaproperties.MediaEncodingProfile], custom_media_sink: typing.Optional[winsdk.windows.media.IMediaExtension]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def start_record_to_custom_sink_async(self, encoding_profile: typing.Optional[winsdk.windows.media.mediaproperties.MediaEncodingProfile], custom_sink_activation_id: str, custom_sink_settings: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> winsdk.windows.foundation.IAsyncAction: ...
    def start_record_to_storage_file_async(self, encoding_profile: typing.Optional[winsdk.windows.media.mediaproperties.MediaEncodingProfile], file: typing.Optional[winsdk.windows.storage.IStorageFile]) -> winsdk.windows.foundation.IAsyncAction: ...
    def start_record_to_stream_async(self, encoding_profile: typing.Optional[winsdk.windows.media.mediaproperties.MediaEncodingProfile], stream: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]) -> winsdk.windows.foundation.IAsyncAction: ...
    def stop_preview_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def stop_record_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def stop_record_with_result_async(self) -> winsdk.windows.foundation.IAsyncOperation[MediaCaptureStopResult]: ...
    def add_failed(self, error_event_handler: typing.Optional[MediaCaptureFailedEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_failed(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_record_limitation_exceeded(self, record_limitation_exceeded_event_handler: typing.Optional[RecordLimitationExceededEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_record_limitation_exceeded(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_focus_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaCapture, MediaCaptureFocusChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_focus_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_photo_confirmation_captured(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaCapture, PhotoConfirmationCapturedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_photo_confirmation_captured(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_camera_stream_state_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaCapture, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_camera_stream_state_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_thermal_status_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaCapture, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_thermal_status_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_capture_device_exclusive_control_status_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaCapture, MediaCaptureDeviceExclusiveControlStatusChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_capture_device_exclusive_control_status_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaCaptureDeviceExclusiveControlStatusChangedEventArgs(winsdk.system.Object):
    device_id: str
    status: MediaCaptureDeviceExclusiveControlStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaCaptureDeviceExclusiveControlStatusChangedEventArgs: ...

class MediaCaptureFailedEventArgs(winsdk.system.Object):
    code: winsdk.system.UInt32
    message: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaCaptureFailedEventArgs: ...

class MediaCaptureFocusChangedEventArgs(winsdk.system.Object):
    focus_state: winsdk.windows.media.devices.MediaCaptureFocusState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaCaptureFocusChangedEventArgs: ...

class MediaCaptureInitializationSettings(winsdk.system.Object):
    video_device_id: str
    streaming_capture_mode: StreamingCaptureMode
    photo_capture_source: PhotoCaptureSource
    audio_device_id: str
    media_category: MediaCategory
    audio_processing: winsdk.windows.media.AudioProcessing
    video_source: typing.Optional[winsdk.windows.media.core.IMediaSource]
    audio_source: typing.Optional[winsdk.windows.media.core.IMediaSource]
    video_profile: typing.Optional[MediaCaptureVideoProfile]
    record_media_description: typing.Optional[MediaCaptureVideoProfileMediaDescription]
    preview_media_description: typing.Optional[MediaCaptureVideoProfileMediaDescription]
    photo_media_description: typing.Optional[MediaCaptureVideoProfileMediaDescription]
    source_group: typing.Optional[winsdk.windows.media.capture.frames.MediaFrameSourceGroup]
    sharing_mode: MediaCaptureSharingMode
    memory_preference: MediaCaptureMemoryPreference
    always_play_system_shutter_sound: winsdk.system.Boolean
    device_uri_password_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    device_uri: typing.Optional[winsdk.windows.foundation.Uri]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaCaptureInitializationSettings: ...
    def __new__(cls: typing.Type[MediaCaptureInitializationSettings]) -> MediaCaptureInitializationSettings:...

class MediaCapturePauseResult(winsdk.system.Object):
    last_frame: typing.Optional[winsdk.windows.media.VideoFrame]
    record_duration: datetime.timedelta
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaCapturePauseResult: ...
    def close(self) -> None: ...

class MediaCaptureRelativePanelWatcher(winsdk.system.Object):
    relative_panel: winsdk.windows.devices.enumeration.Panel
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaCaptureRelativePanelWatcher: ...
    def close(self) -> None: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...
    def add_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaCaptureRelativePanelWatcher, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaCaptureSettings(winsdk.system.Object):
    audio_device_id: str
    photo_capture_source: PhotoCaptureSource
    streaming_capture_mode: StreamingCaptureMode
    video_device_characteristic: VideoDeviceCharacteristic
    video_device_id: str
    audio_processing: winsdk.windows.media.AudioProcessing
    camera_sound_required_for_region: winsdk.system.Boolean
    concurrent_record_and_photo_sequence_supported: winsdk.system.Boolean
    concurrent_record_and_photo_supported: winsdk.system.Boolean
    horizontal35mm_equivalent_focal_length: typing.Optional[typing.Optional[winsdk.system.UInt32]]
    media_category: MediaCategory
    pitch_offset_degrees: typing.Optional[typing.Optional[winsdk.system.Int32]]
    vertical35mm_equivalent_focal_length: typing.Optional[typing.Optional[winsdk.system.UInt32]]
    direct3_d11_device: typing.Optional[winsdk.windows.graphics.directx.direct3d11.IDirect3DDevice]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaCaptureSettings: ...

class MediaCaptureStopResult(winsdk.system.Object):
    last_frame: typing.Optional[winsdk.windows.media.VideoFrame]
    record_duration: datetime.timedelta
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaCaptureStopResult: ...
    def close(self) -> None: ...

class MediaCaptureVideoProfile(winsdk.system.Object):
    id: str
    supported_photo_media_description: typing.Optional[winsdk.windows.foundation.collections.IVectorView[MediaCaptureVideoProfileMediaDescription]]
    supported_preview_media_description: typing.Optional[winsdk.windows.foundation.collections.IVectorView[MediaCaptureVideoProfileMediaDescription]]
    supported_record_media_description: typing.Optional[winsdk.windows.foundation.collections.IVectorView[MediaCaptureVideoProfileMediaDescription]]
    video_device_id: str
    frame_source_infos: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.media.capture.frames.MediaFrameSourceInfo]]
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[winsdk.system.Guid, winsdk.system.Object]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaCaptureVideoProfile: ...
    def get_concurrency(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[MediaCaptureVideoProfile]]: ...

class MediaCaptureVideoProfileMediaDescription(winsdk.system.Object):
    frame_rate: winsdk.system.Double
    height: winsdk.system.UInt32
    is_hdr_video_supported: winsdk.system.Boolean
    is_variable_photo_sequence_supported: winsdk.system.Boolean
    width: winsdk.system.UInt32
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[winsdk.system.Guid, winsdk.system.Object]]
    subtype: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaCaptureVideoProfileMediaDescription: ...

class OptionalReferencePhotoCapturedEventArgs(winsdk.system.Object):
    context: typing.Optional[winsdk.system.Object]
    frame: typing.Optional[CapturedFrame]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> OptionalReferencePhotoCapturedEventArgs: ...

class PhotoCapturedEventArgs(winsdk.system.Object):
    capture_time_offset: datetime.timedelta
    frame: typing.Optional[CapturedFrame]
    thumbnail: typing.Optional[CapturedFrame]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PhotoCapturedEventArgs: ...

class PhotoConfirmationCapturedEventArgs(winsdk.system.Object):
    capture_time_offset: datetime.timedelta
    frame: typing.Optional[CapturedFrame]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PhotoConfirmationCapturedEventArgs: ...

class ScreenCapture(winsdk.system.Object):
    audio_source: typing.Optional[winsdk.windows.media.core.IMediaSource]
    is_audio_suspended: winsdk.system.Boolean
    is_video_suspended: winsdk.system.Boolean
    video_source: typing.Optional[winsdk.windows.media.core.IMediaSource]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ScreenCapture: ...
    @staticmethod
    def get_for_current_view() -> typing.Optional[ScreenCapture]: ...
    def add_source_suspension_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[ScreenCapture, SourceSuspensionChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_source_suspension_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class SourceSuspensionChangedEventArgs(winsdk.system.Object):
    is_audio_suspended: winsdk.system.Boolean
    is_video_suspended: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SourceSuspensionChangedEventArgs: ...

class VideoStreamConfiguration(winsdk.system.Object):
    input_properties: typing.Optional[winsdk.windows.media.mediaproperties.VideoEncodingProperties]
    output_properties: typing.Optional[winsdk.windows.media.mediaproperties.VideoEncodingProperties]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VideoStreamConfiguration: ...

MediaCaptureFailedEventHandler = typing.Callable[[typing.Optional[MediaCapture], typing.Optional[MediaCaptureFailedEventArgs]], None]

RecordLimitationExceededEventHandler = typing.Callable[[typing.Optional[MediaCapture]], None]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.I2c.Provider")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class ProviderI2cBusSpeed(enum.IntEnum):
    STANDARD_MODE = 0
    FAST_MODE = 1

class ProviderI2cSharingMode(enum.IntEnum):
    EXCLUSIVE = 0
    SHARED = 1

class ProviderI2cTransferStatus(enum.IntEnum):
    FULL_TRANSFER = 0
    PARTIAL_TRANSFER = 1
    SLAVE_ADDRESS_NOT_ACKNOWLEDGED = 2

_ns_module._register_ProviderI2cBusSpeed(ProviderI2cBusSpeed)
_ns_module._register_ProviderI2cSharingMode(ProviderI2cSharingMode)
_ns_module._register_ProviderI2cTransferStatus(ProviderI2cTransferStatus)

ProviderI2cTransferResult = _ns_module.ProviderI2cTransferResult
ProviderI2cConnectionSettings = _ns_module.ProviderI2cConnectionSettings
II2cControllerProvider = _ns_module.II2cControllerProvider
II2cDeviceProvider = _ns_module.II2cDeviceProvider
II2cProvider = _ns_module.II2cProvider
